@@ -2,8 +2,8 @@
 
 use crate::patterns::success_enum::FFIError;
 use crate::types::{
-    ambiguous1, ambiguous2, common, some_foreign_type, Array, Callbacku8u8, Empty, EnumDocumented, Generic, Generic2, Generic3, Opaque, Phantom, SomeForeignType,
-    StructDocumented, Tupled, Vec3f32, Visibility1, Visibility2, Weird1, Weird2,
+    ambiguous1, ambiguous2, common, some_foreign_type, Array, Callbacku8u8, Empty, EnumDocumented, Generic, Generic2, Generic3, Generic4, Opaque, Phantom,
+    SomeForeignType, StructDocumented, Tupled, Vec3f32, Visibility1, Visibility2, Weird1, Weird2,
 };
 use interoptopus::ffi_function;
 use interoptopus::patterns::success_enum::panics_and_errors_to_ffi_enum;
@@ -159,25 +159,31 @@ pub extern "C" fn callback(callback: Callbacku8u8, value: u8) -> u8 {
 
 #[ffi_function]
 #[no_mangle]
-pub extern "C" fn generic_1(x: Generic<u32>, _y: Phantom<u8>) -> u32 {
+pub extern "C" fn generic_1a(x: Generic<u32>, _y: Phantom<u8>) -> u32 {
     *x.x
 }
 
 #[ffi_function]
 #[no_mangle]
-pub extern "C" fn generic_2(x: Generic<u8>, _y: Phantom<u8>) -> u8 {
+pub extern "C" fn generic_1b(x: Generic<u8>, _y: Phantom<u8>) -> u8 {
     *x.x
 }
 
 #[ffi_function]
 #[no_mangle]
-pub extern "C" fn generic_3(x: &Generic2<u8>) -> u8 {
+pub extern "C" fn generic_2(x: &Generic2<u8>) -> u8 {
     x.x
 }
 
 #[ffi_function]
 #[no_mangle]
-pub extern "C" fn generic_4(x: &Generic3<u8>) -> u8 {
+pub extern "C" fn generic_3(x: &Generic3<u8>) -> u8 {
+    x.x
+}
+
+#[ffi_function]
+#[no_mangle]
+pub extern "C" fn generic_4(x: &Generic4<u8>) -> u8 {
     x.x
 }
 
