@@ -2,6 +2,7 @@ use crate::patterns::success_enum::FFIError;
 use interoptopus::patterns::slice::FFISlice;
 use interoptopus::{ffi_function, pattern_service_generated};
 use some_rust_module::{Error, SimpleService};
+use std::marker::PhantomData;
 
 pub mod some_rust_module {
     use crate::patterns::success_enum::FFIError;
@@ -51,6 +52,11 @@ pub mod some_rust_module {
             *x
         }
 
+        // TODO: How to support these?
+        pub fn method_mut_self_ref_slice_limited<'a, 'b>(&mut self, x: &u8, _y: &mut u8, _slice: FFISlice<'a, u8>, _slice2: FFISlice<'b, u8>) -> u8 {
+            *x
+        }
+
         pub fn method_mut_self_ffi_error(&mut self, _slice: FFISlice<u8>) -> FFIError {
             FFIError::Ok
         }
@@ -87,6 +93,7 @@ pattern_service_generated!(
         simple_service_mut_self_void(&mut SimpleService, slice: FFISlice<u8>) -> (): method_mut_self_void,
         simple_service_mut_self_ref(&mut SimpleService, x: &u8, _y: &mut u8) -> u8: method_mut_self_ref,
         simple_service_mut_self_ref_slice(&mut SimpleService, x: &u8, _y: &mut u8, _slice: FFISlice<u8>) -> u8: method_mut_self_ref_slice,
+        simple_service_mut_self_ref_slice_limited<'a, 'b>(&mut SimpleService, x: &u8, _y: &mut u8, _slice: FFISlice<'a, u8>, _slice2: FFISlice<'b, u8>) -> u8: method_mut_self_ref_slice_limited,
         simple_service_mut_self_ffi_error(&mut SimpleService, slice: FFISlice<u8>) -> FFIError: method_mut_self_ffi_error,
         simple_service_void(&SimpleService) -> (): method_void
     ],
